@@ -3,6 +3,7 @@
 
 import sys
 import traceback
+import logging
 import rpcrequest
 import rpcresponse
 import rpcerror
@@ -85,13 +86,21 @@ class JsonRpc(object):
 
             if method not in self.methods:
                 # Method not found error
+                error = rpcerror.MethodNotFound(
+                    data = u"Method name: '%s'" % method
+                )
                 responses.append(
                     rpcresponse.Response(
                         jsonrpc = jsonrpc,
                         id = id,
-                        error = rpcerror.MethodNotFound(
-                            data = u"Method name: '%s'" % method
-                        )
+                        error = error
+                    )
+                )
+                # Logging error
+                logging.error(
+                    u"{error} -- {data}".format(
+                        error = unicode(error),
+                        data = repr(error.data)
                     )
                 )
 
@@ -107,13 +116,21 @@ class JsonRpc(object):
                 # No return value is OK if we don´t have an ID (=notification)
                 if result is None:
                     if id:
+                        error = rpcerror.InternalError(
+                            data = u"No result from JSON-RPC method."
+                        )
                         responses.append(
                             rpcresponse.Response(
                                 jsonrpc = jsonrpc,
                                 id = id,
-                                error = rpcerror.InternalError(
-                                    data = u"No result from JSON-RPC method."
-                                )
+                                error = error
+                            )
+                        )
+                        # Logging error
+                        logging.error(
+                            u"{error} -- {data}".format(
+                                error = unicode(error),
+                                data = repr(error.data)
                             )
                         )
                 else:
@@ -124,19 +141,35 @@ class JsonRpc(object):
             except TypeError, err:
                 traceback_info = "".join(traceback.format_exception(*sys.exc_info()))
                 if "takes exactly" in unicode(err) and "arguments" in unicode(err):
+                    error = rpcerror.InvalidParams(data = traceback_info)
                     responses.append(
                         rpcresponse.Response(
                             jsonrpc = jsonrpc,
                             id = id,
-                            error = rpcerror.InvalidParams(data = traceback_info)
+                            error = error
+                        )
+                    )
+                    # Logging error
+                    logging.error(
+                        u"{error} -- {data}".format(
+                            error = unicode(error),
+                            data = repr(error.data)
                         )
                     )
                 else:
+                    error = rpcerror.InternalError(data = traceback_info)
                     responses.append(
                         rpcresponse.Response(
                             jsonrpc = jsonrpc,
                             id = id,
-                            error = rpcerror.InternalError(data = traceback_info)
+                            error = error
+                        )
+                    )
+                    # Logging error
+                    logging.error(
+                        u"{error} -- {data}".format(
+                            error = unicode(error),
+                            data = repr(error.data)
                         )
                     )
             except rpcerror.JsonRpcError, err:
@@ -147,19 +180,32 @@ class JsonRpc(object):
                         error = err
                     )
                 )
+                # Logging error
+                logging.error(
+                    u"{error} -- {data}".format(
+                        error = unicode(err),
+                        data = repr(err.data)
+                    )
+                )
             except BaseException, err:
                 traceback_info = "".join(traceback.format_exception(*sys.exc_info()))
                 if hasattr(err, "data"):
                     error_data = err.data
                 else:
                     error_data = None
+                error = rpcerror.InternalError(data = error_data or traceback_info)
                 responses.append(
                     rpcresponse.Response(
                         jsonrpc = jsonrpc,
                         id = id,
-                        error = rpcerror.InternalError(
-                            data = error_data or traceback_info
-                        )
+                        error = error
+                    )
+                )
+                # Logging error
+                logging.error(
+                    u"{error} -- {data}".format(
+                        error = unicode(error),
+                        data = repr(error.data)
                     )
                 )
 
